# PascalProjectName

This is a Zrb project.

To learn more about Zrb, please visit the [Zrb homepage](https://pypi.org/project/zrb/).


# How to Start PascalProjectName

```bash
source ./project.sh
zrb
```

Once you invoke the command, PascalProjectName virtual environment will be created.

# PascalProjectName Configurations

See [template.env](template.env)

To make your configuration, please copy `template.env` to `.env`


# Reloading PascalProjectName Configurations

To reload your configurations, you can invoke the following command:

```bash
reload
```

Please note that PascalProjectName's virtual environment has to be activated first.